import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGateway::BasePathMapping`` resource creates a base path that clients who call your API must use in the invocation URL.
 */
export declare class BasePathMapping extends pulumi.CustomResource {
    /**
     * Get an existing BasePathMapping resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): BasePathMapping;
    /**
     * Returns true if the given object is an instance of BasePathMapping.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BasePathMapping;
    /**
     * The base path name that callers of the API must provide as part of the URL after the domain name.
     */
    readonly basePath: pulumi.Output<string | undefined>;
    /**
     * The domain name of the BasePathMapping resource to be described.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    readonly restApiId: pulumi.Output<string | undefined>;
    /**
     * The name of the associated stage.
     */
    readonly stage: pulumi.Output<string | undefined>;
    /**
     * Create a BasePathMapping resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BasePathMappingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a BasePathMapping resource.
 */
export interface BasePathMappingArgs {
    /**
     * The base path name that callers of the API must provide as part of the URL after the domain name.
     */
    basePath?: pulumi.Input<string>;
    /**
     * The domain name of the BasePathMapping resource to be described.
     */
    domainName: pulumi.Input<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId?: pulumi.Input<string>;
    /**
     * The name of the associated stage.
     */
    stage?: pulumi.Input<string>;
}
