import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The ``AWS::ApiGatewayV2::RouteResponse`` resource creates a route response for a WebSocket API. For more information, see [Set up Route Responses for a WebSocket API in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-route-response.html) in the *API Gateway Developer Guide*.
 */
export declare class RouteResponse extends pulumi.CustomResource {
    /**
     * Get an existing RouteResponse resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RouteResponse;
    /**
     * Returns true if the given object is an instance of RouteResponse.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RouteResponse;
    /**
     * The API identifier.
     */
    readonly apiId: pulumi.Output<string>;
    /**
     * The model selection expression for the route response. Supported only for WebSocket APIs.
     */
    readonly modelSelectionExpression: pulumi.Output<string | undefined>;
    /**
     * The response models for the route response.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGatewayV2::RouteResponse` for more information about the expected schema for this property.
     */
    readonly responseModels: pulumi.Output<any | undefined>;
    /**
     * The route response parameters.
     */
    readonly responseParameters: pulumi.Output<{
        [key: string]: outputs.apigatewayv2.RouteResponseParameterConstraints;
    } | undefined>;
    /**
     * The route ID.
     */
    readonly routeId: pulumi.Output<string>;
    /**
     * The route response ID.
     */
    readonly routeResponseId: pulumi.Output<string>;
    /**
     * The route response key.
     */
    readonly routeResponseKey: pulumi.Output<string>;
    /**
     * Create a RouteResponse resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RouteResponseArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RouteResponse resource.
 */
export interface RouteResponseArgs {
    /**
     * The API identifier.
     */
    apiId: pulumi.Input<string>;
    /**
     * The model selection expression for the route response. Supported only for WebSocket APIs.
     */
    modelSelectionExpression?: pulumi.Input<string>;
    /**
     * The response models for the route response.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGatewayV2::RouteResponse` for more information about the expected schema for this property.
     */
    responseModels?: any;
    /**
     * The route response parameters.
     */
    responseParameters?: pulumi.Input<{
        [key: string]: pulumi.Input<inputs.apigatewayv2.RouteResponseParameterConstraintsArgs>;
    }>;
    /**
     * The route ID.
     */
    routeId: pulumi.Input<string>;
    /**
     * The route response key.
     */
    routeResponseKey: pulumi.Input<string>;
}
