import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Represents an association between an ID namespace and a collaboration
 */
export declare class IdNamespaceAssociation extends pulumi.CustomResource {
    /**
     * Get an existing IdNamespaceAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IdNamespaceAssociation;
    /**
     * Returns true if the given object is an instance of IdNamespaceAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdNamespaceAssociation;
    /**
     * The Amazon Resource Name (ARN) of the ID namespace association.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the collaboration that contains this ID namespace association.
     */
    readonly collaborationArn: pulumi.Output<string>;
    /**
     * The unique identifier of the collaboration that contains this ID namespace association.
     */
    readonly collaborationIdentifier: pulumi.Output<string>;
    /**
     * The description of the ID namespace association.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The configuration settings for the ID mapping table.
     */
    readonly idMappingConfig: pulumi.Output<outputs.cleanrooms.IdNamespaceAssociationIdMappingConfig | undefined>;
    /**
     * The unique identifier of the ID namespace association that you want to retrieve.
     */
    readonly idNamespaceAssociationIdentifier: pulumi.Output<string>;
    /**
     * The input reference configuration for the ID namespace association.
     */
    readonly inputReferenceConfig: pulumi.Output<outputs.cleanrooms.IdNamespaceAssociationInputReferenceConfig>;
    readonly inputReferenceProperties: pulumi.Output<outputs.cleanrooms.IdNamespaceAssociationInputReferenceProperties>;
    /**
     * The Amazon Resource Name (ARN) of the membership resource for this ID namespace association.
     */
    readonly membershipArn: pulumi.Output<string>;
    /**
     * The unique identifier of the membership that contains the ID namespace association.
     */
    readonly membershipIdentifier: pulumi.Output<string>;
    /**
     * The name of this ID namespace association.
     */
    readonly name: pulumi.Output<string>;
    /**
     * An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a IdNamespaceAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdNamespaceAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IdNamespaceAssociation resource.
 */
export interface IdNamespaceAssociationArgs {
    /**
     * The description of the ID namespace association.
     */
    description?: pulumi.Input<string>;
    /**
     * The configuration settings for the ID mapping table.
     */
    idMappingConfig?: pulumi.Input<inputs.cleanrooms.IdNamespaceAssociationIdMappingConfigArgs>;
    /**
     * The input reference configuration for the ID namespace association.
     */
    inputReferenceConfig: pulumi.Input<inputs.cleanrooms.IdNamespaceAssociationInputReferenceConfigArgs>;
    /**
     * The unique identifier of the membership that contains the ID namespace association.
     */
    membershipIdentifier: pulumi.Input<string>;
    /**
     * The name of this ID namespace association.
     */
    name?: pulumi.Input<string>;
    /**
     * An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
