import * as pulumi from "@pulumi/pulumi";
/**
 * The key value store. Use this to separate data from function code, allowing you to update data without having to publish a new version of a function. The key value store holds keys and their corresponding values.
 */
export declare function getKeyValueStore(args: GetKeyValueStoreArgs, opts?: pulumi.InvokeOptions): Promise<GetKeyValueStoreResult>;
export interface GetKeyValueStoreArgs {
    /**
     * The name of the key value store.
     */
    name: string;
}
export interface GetKeyValueStoreResult {
    /**
     * The Amazon Resource Name (ARN) of the key value store.
     */
    readonly arn?: string;
    /**
     * A comment for the key value store.
     */
    readonly comment?: string;
    /**
     * The unique Id for the key value store.
     */
    readonly id?: string;
    /**
     * The current status of the key value store. For more information, see [Key value store statuses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/kvs-with-functions-create.html#key-value-store-status) in the *.*
     */
    readonly status?: string;
}
/**
 * The key value store. Use this to separate data from function code, allowing you to update data without having to publish a new version of a function. The key value store holds keys and their corresponding values.
 */
export declare function getKeyValueStoreOutput(args: GetKeyValueStoreOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetKeyValueStoreResult>;
export interface GetKeyValueStoreOutputArgs {
    /**
     * The name of the key value store.
     */
    name: pulumi.Input<string>;
}
