import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Cognito::UserPoolRiskConfigurationAttachment
 */
export declare class UserPoolRiskConfigurationAttachment extends pulumi.CustomResource {
    /**
     * Get an existing UserPoolRiskConfigurationAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): UserPoolRiskConfigurationAttachment;
    /**
     * Returns true if the given object is an instance of UserPoolRiskConfigurationAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UserPoolRiskConfigurationAttachment;
    /**
     * The settings for automated responses and notification templates for adaptive authentication with threat protection.
     */
    readonly accountTakeoverRiskConfiguration: pulumi.Output<outputs.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverRiskConfigurationType | undefined>;
    /**
     * The app client where this configuration is applied. When this parameter isn't present, the risk configuration applies to all user pool app clients that don't have client-level settings.
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * Settings for compromised-credentials actions and authentication types with threat protection in full-function `ENFORCED` mode.
     */
    readonly compromisedCredentialsRiskConfiguration: pulumi.Output<outputs.cognito.UserPoolRiskConfigurationAttachmentCompromisedCredentialsRiskConfigurationType | undefined>;
    /**
     * Exceptions to the risk evaluation configuration, including always-allow and always-block IP address ranges.
     */
    readonly riskExceptionConfiguration: pulumi.Output<outputs.cognito.UserPoolRiskConfigurationAttachmentRiskExceptionConfigurationType | undefined>;
    /**
     * The ID of the user pool that has the risk configuration applied.
     */
    readonly userPoolId: pulumi.Output<string>;
    /**
     * Create a UserPoolRiskConfigurationAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserPoolRiskConfigurationAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a UserPoolRiskConfigurationAttachment resource.
 */
export interface UserPoolRiskConfigurationAttachmentArgs {
    /**
     * The settings for automated responses and notification templates for adaptive authentication with threat protection.
     */
    accountTakeoverRiskConfiguration?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverRiskConfigurationTypeArgs>;
    /**
     * The app client where this configuration is applied. When this parameter isn't present, the risk configuration applies to all user pool app clients that don't have client-level settings.
     */
    clientId: pulumi.Input<string>;
    /**
     * Settings for compromised-credentials actions and authentication types with threat protection in full-function `ENFORCED` mode.
     */
    compromisedCredentialsRiskConfiguration?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentCompromisedCredentialsRiskConfigurationTypeArgs>;
    /**
     * Exceptions to the risk evaluation configuration, including always-allow and always-block IP address ranges.
     */
    riskExceptionConfiguration?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentRiskExceptionConfigurationTypeArgs>;
    /**
     * The ID of the user pool that has the risk configuration applied.
     */
    userPoolId: pulumi.Input<string>;
}
