import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::PhoneNumber
 */
export declare class PhoneNumber extends pulumi.CustomResource {
    /**
     * Get an existing PhoneNumber resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PhoneNumber;
    /**
     * Returns true if the given object is an instance of PhoneNumber.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PhoneNumber;
    /**
     * The phone number e164 address.
     */
    readonly address: pulumi.Output<string>;
    /**
     * The phone number country code.
     */
    readonly countryCode: pulumi.Output<string | undefined>;
    /**
     * The description of the phone number.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The phone number ARN
     */
    readonly phoneNumberArn: pulumi.Output<string>;
    /**
     * The phone number prefix.
     */
    readonly prefix: pulumi.Output<string | undefined>;
    /**
     * The source phone number arn.
     */
    readonly sourcePhoneNumberArn: pulumi.Output<string | undefined>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ARN of the target the phone number is claimed to.
     */
    readonly targetArn: pulumi.Output<string>;
    /**
     * The phone number type
     */
    readonly type: pulumi.Output<string | undefined>;
    /**
     * Create a PhoneNumber resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PhoneNumberArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PhoneNumber resource.
 */
export interface PhoneNumberArgs {
    /**
     * The phone number country code.
     */
    countryCode?: pulumi.Input<string>;
    /**
     * The description of the phone number.
     */
    description?: pulumi.Input<string>;
    /**
     * The phone number prefix.
     */
    prefix?: pulumi.Input<string>;
    /**
     * The source phone number arn.
     */
    sourcePhoneNumberArn?: pulumi.Input<string>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ARN of the target the phone number is claimed to.
     */
    targetArn: pulumi.Input<string>;
    /**
     * The phone number type
     */
    type?: pulumi.Input<string>;
}
