import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::ConnectCampaigns::Campaign Resource Type
 */
export declare class Campaign extends pulumi.CustomResource {
    /**
     * Get an existing Campaign resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Campaign;
    /**
     * Returns true if the given object is an instance of Campaign.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Campaign;
    /**
     * Amazon Connect Campaign Arn
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Amazon Connect Instance Arn
     */
    readonly connectInstanceArn: pulumi.Output<string>;
    /**
     * Contains information about the dialer configuration.
     */
    readonly dialerConfig: pulumi.Output<outputs.connectcampaigns.CampaignDialerConfig>;
    /**
     * Amazon Connect Campaign Name
     */
    readonly name: pulumi.Output<string>;
    /**
     * Contains information about the outbound call configuration.
     */
    readonly outboundCallConfig: pulumi.Output<outputs.connectcampaigns.CampaignOutboundCallConfig>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Campaign resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CampaignArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Campaign resource.
 */
export interface CampaignArgs {
    /**
     * Amazon Connect Instance Arn
     */
    connectInstanceArn: pulumi.Input<string>;
    /**
     * Contains information about the dialer configuration.
     */
    dialerConfig: pulumi.Input<inputs.connectcampaigns.CampaignDialerConfigArgs>;
    /**
     * Amazon Connect Campaign Name
     */
    name?: pulumi.Input<string>;
    /**
     * Contains information about the outbound call configuration.
     */
    outboundCallConfig: pulumi.Input<inputs.connectcampaigns.CampaignOutboundCallConfigArgs>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
