import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A domain is an organizing entity for connecting together assets, users, and their projects
 */
export declare class Domain extends pulumi.CustomResource {
    /**
     * Get an existing Domain resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Domain;
    /**
     * Returns true if the given object is an instance of Domain.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Domain;
    /**
     * The ARN of the Amazon DataZone domain.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The id of the Amazon DataZone domain.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp of when the Amazon DataZone domain was last updated.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the Amazon DataZone domain.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the AWS account that houses the Amazon DataZone domain.
     */
    readonly domainExecutionRole: pulumi.Output<string>;
    /**
     * The version of the domain.
     */
    readonly domainVersion: pulumi.Output<enums.datazone.DomainVersion | undefined>;
    /**
     * The identifier of the AWS Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
     */
    readonly kmsKeyIdentifier: pulumi.Output<string | undefined>;
    /**
     * The timestamp of when the Amazon DataZone domain was last updated.
     */
    readonly lastUpdatedAt: pulumi.Output<string>;
    /**
     * The identifier of the AWS account that manages the domain.
     */
    readonly managedAccountId: pulumi.Output<string>;
    /**
     * The name of the Amazon DataZone domain.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The URL of the data portal for this Amazon DataZone domain.
     */
    readonly portalUrl: pulumi.Output<string>;
    /**
     * The ID of the root domain in Amazon Datazone.
     */
    readonly rootDomainUnitId: pulumi.Output<string>;
    /**
     * The service role of the domain that is created.
     */
    readonly serviceRole: pulumi.Output<string | undefined>;
    /**
     * The single-sign on configuration of the Amazon DataZone domain.
     */
    readonly singleSignOn: pulumi.Output<outputs.datazone.DomainSingleSignOn | undefined>;
    /**
     * The status of the Amazon DataZone domain.
     */
    readonly status: pulumi.Output<enums.datazone.DomainStatus>;
    /**
     * The tags specified for the Amazon DataZone domain.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Domain resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DomainArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Domain resource.
 */
export interface DomainArgs {
    /**
     * The description of the Amazon DataZone domain.
     */
    description?: pulumi.Input<string>;
    /**
     * The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the AWS account that houses the Amazon DataZone domain.
     */
    domainExecutionRole: pulumi.Input<string>;
    /**
     * The version of the domain.
     */
    domainVersion?: pulumi.Input<enums.datazone.DomainVersion>;
    /**
     * The identifier of the AWS Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
     */
    kmsKeyIdentifier?: pulumi.Input<string>;
    /**
     * The name of the Amazon DataZone domain.
     */
    name?: pulumi.Input<string>;
    /**
     * The service role of the domain that is created.
     */
    serviceRole?: pulumi.Input<string>;
    /**
     * The single-sign on configuration of the Amazon DataZone domain.
     */
    singleSignOn?: pulumi.Input<inputs.datazone.DomainSingleSignOnArgs>;
    /**
     * The tags specified for the Amazon DataZone domain.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
