import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A user profile represents Amazon DataZone users. Amazon DataZone supports both IAM roles and SSO identities to interact with the Amazon DataZone Management Console and the data portal for different purposes. Domain administrators use IAM roles to perform the initial administrative domain-related work in the Amazon DataZone Management Console, including creating new Amazon DataZone domains, configuring metadata form types, and implementing policies. Data workers use their SSO corporate identities via Identity Center to log into the Amazon DataZone Data Portal and access projects where they have memberships.
 */
export declare function getUserProfile(args: GetUserProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetUserProfileResult>;
export interface GetUserProfileArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the user profile is created.
     */
    domainId: string;
    /**
     * The ID of the Amazon DataZone user profile.
     */
    id: string;
}
export interface GetUserProfileResult {
    readonly details?: outputs.datazone.UserProfileDetails0Properties | outputs.datazone.UserProfileDetails1Properties;
    /**
     * The identifier of the Amazon DataZone domain in which the user profile is created.
     */
    readonly domainId?: string;
    /**
     * The ID of the Amazon DataZone user profile.
     */
    readonly id?: string;
    /**
     * The status of the user profile.
     */
    readonly status?: enums.datazone.UserProfileStatus;
    /**
     * The type of the user profile.
     */
    readonly type?: enums.datazone.UserProfileType;
}
/**
 * A user profile represents Amazon DataZone users. Amazon DataZone supports both IAM roles and SSO identities to interact with the Amazon DataZone Management Console and the data portal for different purposes. Domain administrators use IAM roles to perform the initial administrative domain-related work in the Amazon DataZone Management Console, including creating new Amazon DataZone domains, configuring metadata form types, and implementing policies. Data workers use their SSO corporate identities via Identity Center to log into the Amazon DataZone Data Portal and access projects where they have memberships.
 */
export declare function getUserProfileOutput(args: GetUserProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserProfileResult>;
export interface GetUserProfileOutputArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the user profile is created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone user profile.
     */
    id: pulumi.Input<string>;
}
