import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Deadline::Queue Resource Type
 */
export declare class Queue extends pulumi.CustomResource {
    /**
     * Get an existing Queue resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Queue;
    /**
     * Returns true if the given object is an instance of Queue.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Queue;
    /**
     * The identifiers of the storage profiles that this queue can use to share assets between workers using different operating systems.
     */
    readonly allowedStorageProfileIds: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the queue.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The default action taken on a queue summary if a budget wasn't configured.
     */
    readonly defaultBudgetAction: pulumi.Output<enums.deadline.QueueDefaultQueueBudgetAction | undefined>;
    /**
     * A description of the queue that helps identify what the queue is used for.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the queue summary to update.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * The farm ID.
     */
    readonly farmId: pulumi.Output<string>;
    /**
     * The job attachment settings. These are the Amazon S3 bucket name and the Amazon S3 prefix.
     */
    readonly jobAttachmentSettings: pulumi.Output<outputs.deadline.QueueJobAttachmentSettings | undefined>;
    /**
     * Identifies the user for a job.
     */
    readonly jobRunAsUser: pulumi.Output<outputs.deadline.QueueJobRunAsUser | undefined>;
    /**
     * The queue ID.
     */
    readonly queueId: pulumi.Output<string>;
    /**
     * The file system location that the queue uses.
     */
    readonly requiredFileSystemLocationNames: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role that workers use when running jobs in this queue.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Queue resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: QueueArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Queue resource.
 */
export interface QueueArgs {
    /**
     * The identifiers of the storage profiles that this queue can use to share assets between workers using different operating systems.
     */
    allowedStorageProfileIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The default action taken on a queue summary if a budget wasn't configured.
     */
    defaultBudgetAction?: pulumi.Input<enums.deadline.QueueDefaultQueueBudgetAction>;
    /**
     * A description of the queue that helps identify what the queue is used for.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the queue summary to update.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    displayName: pulumi.Input<string>;
    /**
     * The farm ID.
     */
    farmId: pulumi.Input<string>;
    /**
     * The job attachment settings. These are the Amazon S3 bucket name and the Amazon S3 prefix.
     */
    jobAttachmentSettings?: pulumi.Input<inputs.deadline.QueueJobAttachmentSettingsArgs>;
    /**
     * Identifies the user for a job.
     */
    jobRunAsUser?: pulumi.Input<inputs.deadline.QueueJobRunAsUserArgs>;
    /**
     * The file system location that the queue uses.
     */
    requiredFileSystemLocationNames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role that workers use when running jobs in this queue.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
