import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::Detective::MemberInvitation
 */
export declare class MemberInvitation extends pulumi.CustomResource {
    /**
     * Get an existing MemberInvitation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MemberInvitation;
    /**
     * Returns true if the given object is an instance of MemberInvitation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MemberInvitation;
    /**
     * When set to true, invitation emails are not sent to the member accounts. Member accounts must still accept the invitation before they are added to the behavior graph. Updating this field has no effect.
     */
    readonly disableEmailNotification: pulumi.Output<boolean | undefined>;
    /**
     * The ARN of the graph to which the member account will be invited
     */
    readonly graphArn: pulumi.Output<string>;
    /**
     * The root email address for the account to be invited, for validation. Updating this field has no effect.
     */
    readonly memberEmailAddress: pulumi.Output<string>;
    /**
     * The AWS account ID to be invited to join the graph as a member
     */
    readonly memberId: pulumi.Output<string>;
    /**
     * A message to be included in the email invitation sent to the invited account. Updating this field has no effect.
     */
    readonly message: pulumi.Output<string | undefined>;
    /**
     * Create a MemberInvitation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MemberInvitationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MemberInvitation resource.
 */
export interface MemberInvitationArgs {
    /**
     * When set to true, invitation emails are not sent to the member accounts. Member accounts must still accept the invitation before they are added to the behavior graph. Updating this field has no effect.
     */
    disableEmailNotification?: pulumi.Input<boolean>;
    /**
     * The ARN of the graph to which the member account will be invited
     */
    graphArn: pulumi.Input<string>;
    /**
     * The root email address for the account to be invited, for validation. Updating this field has no effect.
     */
    memberEmailAddress: pulumi.Input<string>;
    /**
     * The AWS account ID to be invited to join the graph as a member
     */
    memberId: pulumi.Input<string>;
    /**
     * A message to be included in the email invitation sent to the invited account. Updating this field has no effect.
     */
    message?: pulumi.Input<string>;
}
