import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DMS::DataMigration.
 */
export declare class DataMigration extends pulumi.CustomResource {
    /**
     * Get an existing DataMigration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DataMigration;
    /**
     * Returns true if the given object is an instance of DataMigration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DataMigration;
    /**
     * The property describes an ARN of the data migration.
     */
    readonly dataMigrationArn: pulumi.Output<string>;
    /**
     * The property describes the create time of the data migration.
     */
    readonly dataMigrationCreateTime: pulumi.Output<string>;
    /**
     * The property describes an ARN of the data migration.
     */
    readonly dataMigrationIdentifier: pulumi.Output<string | undefined>;
    /**
     * The property describes a name to identify the data migration.
     */
    readonly dataMigrationName: pulumi.Output<string | undefined>;
    /**
     * The property describes the settings for the data migration.
     */
    readonly dataMigrationSettings: pulumi.Output<outputs.dms.DataMigrationSettings | undefined>;
    /**
     * The property describes the type of migration.
     */
    readonly dataMigrationType: pulumi.Output<enums.dms.DataMigrationType>;
    /**
     * The property describes an identifier for the migration project. It is used for describing/deleting/modifying can be name/arn
     */
    readonly migrationProjectIdentifier: pulumi.Output<string>;
    /**
     * The property describes Amazon Resource Name (ARN) of the service access role.
     */
    readonly serviceAccessRoleArn: pulumi.Output<string>;
    /**
     * The property describes the settings for the data migration.
     */
    readonly sourceDataSettings: pulumi.Output<outputs.dms.DataMigrationSourceDataSettings[] | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DataMigration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DataMigrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DataMigration resource.
 */
export interface DataMigrationArgs {
    /**
     * The property describes an ARN of the data migration.
     */
    dataMigrationIdentifier?: pulumi.Input<string>;
    /**
     * The property describes a name to identify the data migration.
     */
    dataMigrationName?: pulumi.Input<string>;
    /**
     * The property describes the settings for the data migration.
     */
    dataMigrationSettings?: pulumi.Input<inputs.dms.DataMigrationSettingsArgs>;
    /**
     * The property describes the type of migration.
     */
    dataMigrationType: pulumi.Input<enums.dms.DataMigrationType>;
    /**
     * The property describes an identifier for the migration project. It is used for describing/deleting/modifying can be name/arn
     */
    migrationProjectIdentifier: pulumi.Input<string>;
    /**
     * The property describes Amazon Resource Name (ARN) of the service access role.
     */
    serviceAccessRoleArn: pulumi.Input<string>;
    /**
     * The property describes the settings for the data migration.
     */
    sourceDataSettings?: pulumi.Input<pulumi.Input<inputs.dms.DataMigrationSourceDataSettingsArgs>[]>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
