import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DMS::MigrationProject
 */
export declare class MigrationProject extends pulumi.CustomResource {
    /**
     * Get an existing MigrationProject resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MigrationProject;
    /**
     * Returns true if the given object is an instance of MigrationProject.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MigrationProject;
    /**
     * The optional description of the migration project.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The property describes an instance profile arn for the migration project. For read
     */
    readonly instanceProfileArn: pulumi.Output<string | undefined>;
    /**
     * The property describes an instance profile identifier for the migration project. For create
     */
    readonly instanceProfileIdentifier: pulumi.Output<string | undefined>;
    /**
     * The property describes an instance profile name for the migration project. For read
     */
    readonly instanceProfileName: pulumi.Output<string | undefined>;
    /**
     * The property describes an ARN of the migration project.
     */
    readonly migrationProjectArn: pulumi.Output<string>;
    /**
     * The property describes a creating time of the migration project.
     */
    readonly migrationProjectCreationTime: pulumi.Output<string | undefined>;
    /**
     * The property describes an identifier for the migration project. It is used for describing/deleting/modifying can be name/arn
     */
    readonly migrationProjectIdentifier: pulumi.Output<string | undefined>;
    /**
     * The property describes a name to identify the migration project.
     */
    readonly migrationProjectName: pulumi.Output<string | undefined>;
    /**
     * The property describes schema conversion application attributes for the migration project.
     */
    readonly schemaConversionApplicationAttributes: pulumi.Output<outputs.dms.SchemaConversionApplicationAttributesProperties | undefined>;
    /**
     * The property describes source data provider descriptors for the migration project.
     */
    readonly sourceDataProviderDescriptors: pulumi.Output<outputs.dms.MigrationProjectDataProviderDescriptor[] | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The property describes target data provider descriptors for the migration project.
     */
    readonly targetDataProviderDescriptors: pulumi.Output<outputs.dms.MigrationProjectDataProviderDescriptor[] | undefined>;
    /**
     * The property describes transformation rules for the migration project.
     */
    readonly transformationRules: pulumi.Output<string | undefined>;
    /**
     * Create a MigrationProject resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: MigrationProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MigrationProject resource.
 */
export interface MigrationProjectArgs {
    /**
     * The optional description of the migration project.
     */
    description?: pulumi.Input<string>;
    /**
     * The property describes an instance profile arn for the migration project. For read
     */
    instanceProfileArn?: pulumi.Input<string>;
    /**
     * The property describes an instance profile identifier for the migration project. For create
     */
    instanceProfileIdentifier?: pulumi.Input<string>;
    /**
     * The property describes an instance profile name for the migration project. For read
     */
    instanceProfileName?: pulumi.Input<string>;
    /**
     * The property describes a creating time of the migration project.
     */
    migrationProjectCreationTime?: pulumi.Input<string>;
    /**
     * The property describes an identifier for the migration project. It is used for describing/deleting/modifying can be name/arn
     */
    migrationProjectIdentifier?: pulumi.Input<string>;
    /**
     * The property describes a name to identify the migration project.
     */
    migrationProjectName?: pulumi.Input<string>;
    /**
     * The property describes schema conversion application attributes for the migration project.
     */
    schemaConversionApplicationAttributes?: pulumi.Input<inputs.dms.SchemaConversionApplicationAttributesPropertiesArgs>;
    /**
     * The property describes source data provider descriptors for the migration project.
     */
    sourceDataProviderDescriptors?: pulumi.Input<pulumi.Input<inputs.dms.MigrationProjectDataProviderDescriptorArgs>[]>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The property describes target data provider descriptors for the migration project.
     */
    targetDataProviderDescriptors?: pulumi.Input<pulumi.Input<inputs.dms.MigrationProjectDataProviderDescriptorArgs>[]>;
    /**
     * The property describes transformation rules for the migration project.
     */
    transformationRules?: pulumi.Input<string>;
}
