import * as pulumi from "@pulumi/pulumi";
/**
 * Associates an Elastic IP address with an instance or a network interface. Before you can use an Elastic IP address, you must allocate it to your account. For more information about working with Elastic IP addresses, see [Elastic IP address concepts and rules](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#vpc-eip-overview).
 *  You must specify ``AllocationId`` and either ``InstanceId``, ``NetworkInterfaceId``, or ``PrivateIpAddress``.
 */
export declare class EipAssociation extends pulumi.CustomResource {
    /**
     * Get an existing EipAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EipAssociation;
    /**
     * Returns true if the given object is an instance of EipAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EipAssociation;
    /**
     * The allocation ID. This is required.
     */
    readonly allocationId: pulumi.Output<string | undefined>;
    /**
     * The ID of the association.
     */
    readonly awsId: pulumi.Output<string>;
    readonly eip: pulumi.Output<string | undefined>;
    /**
     * The ID of the instance. The instance must have exactly one attached network interface. You can specify either the instance ID or the network interface ID, but not both.
     */
    readonly instanceId: pulumi.Output<string | undefined>;
    /**
     * The ID of the network interface. If the instance has more than one network interface, you must specify a network interface ID.
     *  You can specify either the instance ID or the network interface ID, but not both.
     */
    readonly networkInterfaceId: pulumi.Output<string | undefined>;
    /**
     * The primary or secondary private IP address to associate with the Elastic IP address. If no private IP address is specified, the Elastic IP address is associated with the primary private IP address.
     */
    readonly privateIpAddress: pulumi.Output<string | undefined>;
    /**
     * Create a EipAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EipAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EipAssociation resource.
 */
export interface EipAssociationArgs {
    /**
     * The allocation ID. This is required.
     */
    allocationId?: pulumi.Input<string>;
    eip?: pulumi.Input<string>;
    /**
     * The ID of the instance. The instance must have exactly one attached network interface. You can specify either the instance ID or the network interface ID, but not both.
     */
    instanceId?: pulumi.Input<string>;
    /**
     * The ID of the network interface. If the instance has more than one network interface, you must specify a network interface ID.
     *  You can specify either the instance ID or the network interface ID, but not both.
     */
    networkInterfaceId?: pulumi.Input<string>;
    /**
     * The primary or secondary private IP address to associate with the Elastic IP address. If no private IP address is specified, the Elastic IP address is associated with the primary private IP address.
     */
    privateIpAddress?: pulumi.Input<string>;
}
