import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::EC2::NetworkInsightsAnalysis
 */
export declare function getNetworkInsightsAnalysis(args: GetNetworkInsightsAnalysisArgs, opts?: pulumi.InvokeOptions): Promise<GetNetworkInsightsAnalysisResult>;
export interface GetNetworkInsightsAnalysisArgs {
    /**
     * The ID of the network insights analysis.
     */
    networkInsightsAnalysisId: string;
}
export interface GetNetworkInsightsAnalysisResult {
    /**
     * The member accounts that contain resources that the path can traverse.
     */
    readonly additionalAccounts?: string[];
    /**
     * Potential intermediate components.
     */
    readonly alternatePathHints?: outputs.ec2.NetworkInsightsAnalysisAlternatePathHint[];
    /**
     * The explanations. For more information, see [Reachability Analyzer explanation codes](https://docs.aws.amazon.com/vpc/latest/reachability/explanation-codes.html) .
     */
    readonly explanations?: outputs.ec2.NetworkInsightsAnalysisExplanation[];
    /**
     * The components in the path from source to destination.
     */
    readonly forwardPathComponents?: outputs.ec2.NetworkInsightsAnalysisPathComponent[];
    /**
     * The Amazon Resource Name (ARN) of the network insights analysis.
     */
    readonly networkInsightsAnalysisArn?: string;
    /**
     * The ID of the network insights analysis.
     */
    readonly networkInsightsAnalysisId?: string;
    /**
     * Indicates whether the destination is reachable from the source.
     */
    readonly networkPathFound?: boolean;
    /**
     * The components in the path from destination to source.
     */
    readonly returnPathComponents?: outputs.ec2.NetworkInsightsAnalysisPathComponent[];
    /**
     * The time the analysis started.
     */
    readonly startDate?: string;
    /**
     * The status of the network insights analysis.
     */
    readonly status?: enums.ec2.NetworkInsightsAnalysisStatus;
    /**
     * The status message, if the status is `failed` .
     */
    readonly statusMessage?: string;
    /**
     * The IDs of potential intermediate accounts.
     */
    readonly suggestedAccounts?: string[];
    /**
     * The tags to apply.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::EC2::NetworkInsightsAnalysis
 */
export declare function getNetworkInsightsAnalysisOutput(args: GetNetworkInsightsAnalysisOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetNetworkInsightsAnalysisResult>;
export interface GetNetworkInsightsAnalysisOutputArgs {
    /**
     * The ID of the network insights analysis.
     */
    networkInsightsAnalysisId: pulumi.Input<string>;
}
