import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::EC2::VPCEndpointConnectionNotification
 */
export declare class VpcEndpointConnectionNotification extends pulumi.CustomResource {
    /**
     * Get an existing VpcEndpointConnectionNotification resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcEndpointConnectionNotification;
    /**
     * Returns true if the given object is an instance of VpcEndpointConnectionNotification.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcEndpointConnectionNotification;
    /**
     * The endpoint events for which to receive notifications.
     */
    readonly connectionEvents: pulumi.Output<string[]>;
    /**
     * The ARN of the SNS topic for the notifications.
     */
    readonly connectionNotificationArn: pulumi.Output<string>;
    /**
     * The ID of the endpoint service.
     */
    readonly serviceId: pulumi.Output<string | undefined>;
    /**
     * VPC Endpoint Connection ID generated by service
     */
    readonly vpcEndpointConnectionNotificationId: pulumi.Output<string>;
    /**
     * The ID of the endpoint.
     */
    readonly vpcEndpointId: pulumi.Output<string | undefined>;
    /**
     * Create a VpcEndpointConnectionNotification resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcEndpointConnectionNotificationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcEndpointConnectionNotification resource.
 */
export interface VpcEndpointConnectionNotificationArgs {
    /**
     * The endpoint events for which to receive notifications.
     */
    connectionEvents: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ARN of the SNS topic for the notifications.
     */
    connectionNotificationArn: pulumi.Input<string>;
    /**
     * The ID of the endpoint service.
     */
    serviceId?: pulumi.Input<string>;
    /**
     * The ID of the endpoint.
     */
    vpcEndpointId?: pulumi.Input<string>;
}
