import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::EC2::VPCGatewayAttachment
 */
export declare class VpcGatewayAttachment extends pulumi.CustomResource {
    /**
     * Get an existing VpcGatewayAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcGatewayAttachment;
    /**
     * Returns true if the given object is an instance of VpcGatewayAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcGatewayAttachment;
    /**
     * Used to identify if this resource is an Internet Gateway or Vpn Gateway Attachment
     */
    readonly attachmentType: pulumi.Output<string>;
    /**
     * The ID of the internet gateway. You must specify either InternetGatewayId or VpnGatewayId, but not both.
     */
    readonly internetGatewayId: pulumi.Output<string | undefined>;
    /**
     * The ID of the VPC.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * The ID of the virtual private gateway. You must specify either InternetGatewayId or VpnGatewayId, but not both.
     */
    readonly vpnGatewayId: pulumi.Output<string | undefined>;
    /**
     * Create a VpcGatewayAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcGatewayAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcGatewayAttachment resource.
 */
export interface VpcGatewayAttachmentArgs {
    /**
     * The ID of the internet gateway. You must specify either InternetGatewayId or VpnGatewayId, but not both.
     */
    internetGatewayId?: pulumi.Input<string>;
    /**
     * The ID of the VPC.
     */
    vpcId: pulumi.Input<string>;
    /**
     * The ID of the virtual private gateway. You must specify either InternetGatewayId or VpnGatewayId, but not both.
     */
    vpnGatewayId?: pulumi.Input<string>;
}
