import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A resource schema for a Detector in Amazon Fraud Detector.
 */
export declare function getDetector(args: GetDetectorArgs, opts?: pulumi.InvokeOptions): Promise<GetDetectorResult>;
export interface GetDetectorArgs {
    /**
     * The ARN of the detector.
     */
    arn: string;
}
export interface GetDetectorResult {
    /**
     * The ARN of the detector.
     */
    readonly arn?: string;
    /**
     * The models to associate with this detector.
     */
    readonly associatedModels?: outputs.frauddetector.DetectorModel[];
    /**
     * The time when the detector was created.
     */
    readonly createdTime?: string;
    /**
     * The description of the detector.
     */
    readonly description?: string;
    /**
     * The active version ID of the detector
     */
    readonly detectorVersionId?: string;
    /**
     * The desired detector version status for the detector
     */
    readonly detectorVersionStatus?: enums.frauddetector.DetectorVersionStatus;
    /**
     * The event type to associate this detector with.
     */
    readonly eventType?: outputs.frauddetector.DetectorEventType;
    /**
     * The time when the detector was last updated.
     */
    readonly lastUpdatedTime?: string;
    /**
     * The rule execution mode for the rules included in the detector version.
     *
     * Valid values: `FIRST_MATCHED | ALL_MATCHED` Default value: `FIRST_MATCHED`
     *
     * You can define and edit the rule mode at the detector version level, when it is in draft status.
     *
     * If you specify `FIRST_MATCHED` , Amazon Fraud Detector evaluates rules sequentially, first to last, stopping at the first matched rule. Amazon Fraud dectector then provides the outcomes for that single rule.
     *
     * If you specifiy `ALL_MATCHED` , Amazon Fraud Detector evaluates all rules and returns the outcomes for all matched rules.
     */
    readonly ruleExecutionMode?: enums.frauddetector.DetectorRuleExecutionMode;
    /**
     * The rules to include in the detector version.
     */
    readonly rules?: outputs.frauddetector.DetectorRule[];
    /**
     * Tags associated with this detector.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A resource schema for a Detector in Amazon Fraud Detector.
 */
export declare function getDetectorOutput(args: GetDetectorOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDetectorResult>;
export interface GetDetectorOutputArgs {
    /**
     * The ARN of the detector.
     */
    arn: pulumi.Input<string>;
}
