import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Inspector::AssessmentTarget
 */
export declare class AssessmentTarget extends pulumi.CustomResource {
    /**
     * Get an existing AssessmentTarget resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AssessmentTarget;
    /**
     * Returns true if the given object is an instance of AssessmentTarget.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AssessmentTarget;
    /**
     * The Amazon Resource Name (ARN) that specifies the assessment target that is created.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the Amazon Inspector assessment target. The name must be unique within the AWS account .
     */
    readonly assessmentTargetName: pulumi.Output<string | undefined>;
    /**
     * The ARN that specifies the resource group that is used to create the assessment target. If `resourceGroupArn` is not specified, all EC2 instances in the current AWS account and Region are included in the assessment target.
     */
    readonly resourceGroupArn: pulumi.Output<string | undefined>;
    /**
     * Create a AssessmentTarget resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AssessmentTargetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AssessmentTarget resource.
 */
export interface AssessmentTargetArgs {
    /**
     * The name of the Amazon Inspector assessment target. The name must be unique within the AWS account .
     */
    assessmentTargetName?: pulumi.Input<string>;
    /**
     * The ARN that specifies the resource group that is used to create the assessment target. If `resourceGroupArn` is not specified, all EC2 instances in the current AWS account and Region are included in the assessment target.
     */
    resourceGroupArn?: pulumi.Input<string>;
}
