import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::IoTEvents::Input resource creates an input. To monitor your devices and processes, they must have a way to get telemetry data into ITE. This is done by sending messages as *inputs* to ITE. For more information, see [How to Use](https://docs.aws.amazon.com/iotevents/latest/developerguide/how-to-use-iotevents.html) in the *Developer Guide*.
 */
export declare function getInput(args: GetInputArgs, opts?: pulumi.InvokeOptions): Promise<GetInputResult>;
export interface GetInputArgs {
    /**
     * The name of the input.
     */
    inputName: string;
}
export interface GetInputResult {
    /**
     * The definition of the input.
     */
    readonly inputDefinition?: outputs.iotevents.InputDefinition;
    /**
     * A brief description of the input.
     */
    readonly inputDescription?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     *  For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html).
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::IoTEvents::Input resource creates an input. To monitor your devices and processes, they must have a way to get telemetry data into ITE. This is done by sending messages as *inputs* to ITE. For more information, see [How to Use](https://docs.aws.amazon.com/iotevents/latest/developerguide/how-to-use-iotevents.html) in the *Developer Guide*.
 */
export declare function getInputOutput(args: GetInputOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetInputResult>;
export interface GetInputOutputArgs {
    /**
     * The name of the input.
     */
    inputName: pulumi.Input<string>;
}
