import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Creates a gateway task definition.
 */
export declare class TaskDefinition extends pulumi.CustomResource {
    /**
     * Get an existing TaskDefinition resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TaskDefinition;
    /**
     * Returns true if the given object is an instance of TaskDefinition.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TaskDefinition;
    /**
     * TaskDefinition arn. Returned after successful create.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Whether to automatically create tasks using this task definition for all gateways with the specified current version. If false, the task must me created by calling CreateWirelessGatewayTask.
     */
    readonly autoCreateTasks: pulumi.Output<boolean>;
    /**
     * The ID of the new wireless gateway task definition
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The list of task definitions.
     */
    readonly loRaWanUpdateGatewayTaskEntry: pulumi.Output<outputs.iotwireless.TaskDefinitionLoRaWanUpdateGatewayTaskEntry | undefined>;
    /**
     * The name of the new resource.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the destination.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * A filter to list only the wireless gateway task definitions that use this task definition type
     */
    readonly taskDefinitionType: pulumi.Output<enums.iotwireless.TaskDefinitionType | undefined>;
    /**
     * Information about the gateways to update.
     */
    readonly update: pulumi.Output<outputs.iotwireless.TaskDefinitionUpdateWirelessGatewayTaskCreate | undefined>;
    /**
     * Create a TaskDefinition resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TaskDefinitionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TaskDefinition resource.
 */
export interface TaskDefinitionArgs {
    /**
     * Whether to automatically create tasks using this task definition for all gateways with the specified current version. If false, the task must me created by calling CreateWirelessGatewayTask.
     */
    autoCreateTasks: pulumi.Input<boolean>;
    /**
     * The list of task definitions.
     */
    loRaWanUpdateGatewayTaskEntry?: pulumi.Input<inputs.iotwireless.TaskDefinitionLoRaWanUpdateGatewayTaskEntryArgs>;
    /**
     * The name of the new resource.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the destination.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * A filter to list only the wireless gateway task definitions that use this task definition type
     */
    taskDefinitionType?: pulumi.Input<enums.iotwireless.TaskDefinitionType>;
    /**
     * Information about the gateways to update.
     */
    update?: pulumi.Input<inputs.iotwireless.TaskDefinitionUpdateWirelessGatewayTaskCreateArgs>;
}
