import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Create and manage wireless gateways, including LoRa gateways.
 */
export declare class WirelessGateway extends pulumi.CustomResource {
    /**
     * Get an existing WirelessGateway resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): WirelessGateway;
    /**
     * Returns true if the given object is an instance of WirelessGateway.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WirelessGateway;
    /**
     * Arn for Wireless Gateway. Returned upon successful create.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Id for Wireless Gateway. Returned upon successful create.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Description of Wireless Gateway.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The date and time when the most recent uplink was received.
     */
    readonly lastUplinkReceivedAt: pulumi.Output<string | undefined>;
    /**
     * The combination of Package, Station and Model which represents the version of the LoRaWAN Wireless Gateway.
     */
    readonly loRaWan: pulumi.Output<outputs.iotwireless.WirelessGatewayLoRaWanGateway>;
    /**
     * Name of Wireless Gateway.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the gateway.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Thing Arn. Passed into Update to associate a Thing with the Wireless Gateway.
     */
    readonly thingArn: pulumi.Output<string | undefined>;
    /**
     * Thing Name. If there is a Thing created, this can be returned with a Get call.
     */
    readonly thingName: pulumi.Output<string | undefined>;
    /**
     * Create a WirelessGateway resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WirelessGatewayArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a WirelessGateway resource.
 */
export interface WirelessGatewayArgs {
    /**
     * Description of Wireless Gateway.
     */
    description?: pulumi.Input<string>;
    /**
     * The date and time when the most recent uplink was received.
     */
    lastUplinkReceivedAt?: pulumi.Input<string>;
    /**
     * The combination of Package, Station and Model which represents the version of the LoRaWAN Wireless Gateway.
     */
    loRaWan: pulumi.Input<inputs.iotwireless.WirelessGatewayLoRaWanGatewayArgs>;
    /**
     * Name of Wireless Gateway.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the gateway.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Thing Arn. Passed into Update to associate a Thing with the Wireless Gateway.
     */
    thingArn?: pulumi.Input<string>;
    /**
     * Thing Name. If there is a Thing created, this can be returned with a Get call.
     */
    thingName?: pulumi.Input<string>;
}
