import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IVS::PlaybackRestrictionPolicy.
 */
export declare class PlaybackRestrictionPolicy extends pulumi.CustomResource {
    /**
     * Get an existing PlaybackRestrictionPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PlaybackRestrictionPolicy;
    /**
     * Returns true if the given object is an instance of PlaybackRestrictionPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PlaybackRestrictionPolicy;
    /**
     * A list of country codes that control geoblocking restriction. Allowed values are the officially assigned ISO 3166-1 alpha-2 codes. Default: All countries (an empty array).
     */
    readonly allowedCountries: pulumi.Output<string[]>;
    /**
     * A list of origin sites that control CORS restriction. Allowed values are the same as valid values of the Origin header defined at https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Origin
     */
    readonly allowedOrigins: pulumi.Output<string[]>;
    /**
     * Playback-restriction-policy identifier.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Whether channel playback is constrained by origin site.
     */
    readonly enableStrictOriginEnforcement: pulumi.Output<boolean | undefined>;
    /**
     * Playback-restriction-policy name.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a PlaybackRestrictionPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PlaybackRestrictionPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PlaybackRestrictionPolicy resource.
 */
export interface PlaybackRestrictionPolicyArgs {
    /**
     * A list of country codes that control geoblocking restriction. Allowed values are the officially assigned ISO 3166-1 alpha-2 codes. Default: All countries (an empty array).
     */
    allowedCountries: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A list of origin sites that control CORS restriction. Allowed values are the same as valid values of the Origin header defined at https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Origin
     */
    allowedOrigins: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Whether channel playback is constrained by origin site.
     */
    enableStrictOriginEnforcement?: pulumi.Input<boolean>;
    /**
     * Playback-restriction-policy name.
     */
    name?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
