import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * This structure contains information about one delivery destination in your account.
 *
 * A delivery destination is an AWS resource that represents an AWS service that logs can be sent to CloudWatch Logs, Amazon S3, are supported as Kinesis Data Firehose delivery destinations.
 */
export declare function getDeliveryDestination(args: GetDeliveryDestinationArgs, opts?: pulumi.InvokeOptions): Promise<GetDeliveryDestinationResult>;
export interface GetDeliveryDestinationArgs {
    /**
     * The name of this delivery destination.
     */
    name: string;
}
export interface GetDeliveryDestinationResult {
    /**
     * The Amazon Resource Name (ARN) that uniquely identifies this delivery destination.
     */
    readonly arn?: string;
    /**
     * IAM policy that grants permissions to CloudWatch Logs to deliver logs cross-account to a specified destination in this account.
     *
     * The policy must be in JSON string format.
     *
     * Length Constraints: Maximum length of 51200
     */
    readonly deliveryDestinationPolicy?: outputs.logs.DeliveryDestinationDestinationPolicy;
    /**
     * Displays whether this delivery destination is CloudWatch Logs, Amazon S3, or Kinesis Data Firehose.
     */
    readonly deliveryDestinationType?: string;
    /**
     * The tags that have been assigned to this delivery destination.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * This structure contains information about one delivery destination in your account.
 *
 * A delivery destination is an AWS resource that represents an AWS service that logs can be sent to CloudWatch Logs, Amazon S3, are supported as Kinesis Data Firehose delivery destinations.
 */
export declare function getDeliveryDestinationOutput(args: GetDeliveryDestinationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDeliveryDestinationResult>;
export interface GetDeliveryDestinationOutputArgs {
    /**
     * The name of this delivery destination.
     */
    name: pulumi.Input<string>;
}
