import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::NetworkManager::Link type describes a link.
 */
export declare class Link extends pulumi.CustomResource {
    /**
     * Get an existing Link resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Link;
    /**
     * Returns true if the given object is an instance of Link.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Link;
    /**
     * The Bandwidth for the link.
     */
    readonly bandwidth: pulumi.Output<outputs.networkmanager.LinkBandwidth>;
    /**
     * The date and time that the device was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the link.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the global network.
     */
    readonly globalNetworkId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the link.
     */
    readonly linkArn: pulumi.Output<string>;
    /**
     * The ID of the link.
     */
    readonly linkId: pulumi.Output<string>;
    /**
     * The provider of the link.
     */
    readonly provider: pulumi.Output<string | undefined>;
    /**
     * The ID of the site
     */
    readonly siteId: pulumi.Output<string>;
    /**
     * The state of the link.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The tags for the link.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of the link.
     */
    readonly type: pulumi.Output<string | undefined>;
    /**
     * Create a Link resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LinkArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Link resource.
 */
export interface LinkArgs {
    /**
     * The Bandwidth for the link.
     */
    bandwidth: pulumi.Input<inputs.networkmanager.LinkBandwidthArgs>;
    /**
     * The description of the link.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the global network.
     */
    globalNetworkId: pulumi.Input<string>;
    /**
     * The provider of the link.
     */
    provider?: pulumi.Input<string>;
    /**
     * The ID of the site
     */
    siteId: pulumi.Input<string>;
    /**
     * The tags for the link.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The type of the link.
     */
    type?: pulumi.Input<string>;
}
