import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Creates a package and storage location in an Amazon S3 access point.
 */
export declare class Package extends pulumi.CustomResource {
    /**
     * Get an existing Package resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Package;
    /**
     * Returns true if the given object is an instance of Package.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Package;
    /**
     * The package's ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * When the package was created.
     */
    readonly createdTime: pulumi.Output<number>;
    /**
     * The package's ID.
     */
    readonly packageId: pulumi.Output<string>;
    /**
     * A name for the package.
     */
    readonly packageName: pulumi.Output<string>;
    /**
     * A storage location.
     */
    readonly storageLocation: pulumi.Output<outputs.panorama.PackageStorageLocation | undefined>;
    /**
     * Tags for the package.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Package resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PackageArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Package resource.
 */
export interface PackageArgs {
    /**
     * A name for the package.
     */
    packageName?: pulumi.Input<string>;
    /**
     * A storage location.
     */
    storageLocation?: pulumi.Input<inputs.panorama.PackageStorageLocationArgs>;
    /**
     * Tags for the package.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
