import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Pinpoint::InAppTemplate
 */
export declare class InAppTemplate extends pulumi.CustomResource {
    /**
     * Get an existing InAppTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): InAppTemplate;
    /**
     * Returns true if the given object is an instance of InAppTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is InAppTemplate;
    /**
     * The Amazon Resource Name (ARN) of the message template.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * An object that contains information about the content of an in-app message, including its title and body text, text colors, background colors, images, buttons, and behaviors.
     */
    readonly content: pulumi.Output<outputs.pinpoint.InAppTemplateInAppMessageContent[] | undefined>;
    /**
     * Custom data, in the form of key-value pairs, that is included in an in-app messaging payload.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Pinpoint::InAppTemplate` for more information about the expected schema for this property.
     */
    readonly customConfig: pulumi.Output<any | undefined>;
    /**
     * A string that determines the appearance of the in-app message. You can specify one of the following:
     *
     * - `BOTTOM_BANNER` – a message that appears as a banner at the bottom of the page.
     * - `TOP_BANNER` – a message that appears as a banner at the top of the page.
     * - `OVERLAYS` – a message that covers entire screen.
     * - `MOBILE_FEED` – a message that appears in a window in front of the page.
     * - `MIDDLE_BANNER` – a message that appears as a banner in the middle of the page.
     * - `CAROUSEL` – a scrollable layout of up to five unique messages.
     */
    readonly layout: pulumi.Output<enums.pinpoint.InAppTemplateLayout | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Pinpoint::InAppTemplate` for more information about the expected schema for this property.
     */
    readonly tags: pulumi.Output<any | undefined>;
    /**
     * An optional description of the in-app template.
     */
    readonly templateDescription: pulumi.Output<string | undefined>;
    /**
     * The name of the in-app message template.
     */
    readonly templateName: pulumi.Output<string>;
    /**
     * Create a InAppTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: InAppTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a InAppTemplate resource.
 */
export interface InAppTemplateArgs {
    /**
     * An object that contains information about the content of an in-app message, including its title and body text, text colors, background colors, images, buttons, and behaviors.
     */
    content?: pulumi.Input<pulumi.Input<inputs.pinpoint.InAppTemplateInAppMessageContentArgs>[]>;
    /**
     * Custom data, in the form of key-value pairs, that is included in an in-app messaging payload.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Pinpoint::InAppTemplate` for more information about the expected schema for this property.
     */
    customConfig?: any;
    /**
     * A string that determines the appearance of the in-app message. You can specify one of the following:
     *
     * - `BOTTOM_BANNER` – a message that appears as a banner at the bottom of the page.
     * - `TOP_BANNER` – a message that appears as a banner at the top of the page.
     * - `OVERLAYS` – a message that covers entire screen.
     * - `MOBILE_FEED` – a message that appears in a window in front of the page.
     * - `MIDDLE_BANNER` – a message that appears as a banner in the middle of the page.
     * - `CAROUSEL` – a scrollable layout of up to five unique messages.
     */
    layout?: pulumi.Input<enums.pinpoint.InAppTemplateLayout>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Pinpoint::InAppTemplate` for more information about the expected schema for this property.
     */
    tags?: any;
    /**
     * An optional description of the in-app template.
     */
    templateDescription?: pulumi.Input<string>;
    /**
     * The name of the in-app message template.
     */
    templateName?: pulumi.Input<string>;
}
