import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Creates a new DB shard group for Aurora Limitless Database. You must enable Aurora Limitless Database to create a DB shard group.
 *  Valid for: Aurora DB clusters only
 */
export declare function getDbShardGroup(args: GetDbShardGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetDbShardGroupResult>;
export interface GetDbShardGroupArgs {
    /**
     * The name of the DB shard group.
     */
    dbShardGroupIdentifier: string;
}
export interface GetDbShardGroupResult {
    /**
     * Specifies whether to create standby DB shard groups for the DB shard group. Valid values are the following:
     *   +  0 - Creates a DB shard group without a standby DB shard group. This is the default value.
     *   +  1 - Creates a DB shard group with a standby DB shard group in a different Availability Zone (AZ).
     *   +  2 - Creates a DB shard group with two standby DB shard groups in two different AZs.
     */
    readonly computeRedundancy?: number;
    /**
     * The AWS Region -unique, immutable identifier for the DB shard group.
     */
    readonly dbShardGroupResourceId?: string;
    /**
     * This data type represents the information you need to connect to an Amazon RDS DB instance. This data type is used as a response element in the following actions:
     *
     * - `CreateDBInstance`
     * - `DescribeDBInstances`
     * - `DeleteDBInstance`
     *
     * For the data structure that represents Amazon Aurora DB cluster endpoints, see `DBClusterEndpoint` .
     */
    readonly endpoint?: string;
    /**
     * The maximum capacity of the DB shard group in Aurora capacity units (ACUs).
     */
    readonly maxAcu?: number;
    /**
     * An optional set of key-value pairs to associate arbitrary data of your choosing with the DB shard group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Creates a new DB shard group for Aurora Limitless Database. You must enable Aurora Limitless Database to create a DB shard group.
 *  Valid for: Aurora DB clusters only
 */
export declare function getDbShardGroupOutput(args: GetDbShardGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDbShardGroupResult>;
export interface GetDbShardGroupOutputArgs {
    /**
     * The name of the DB shard group.
     */
    dbShardGroupIdentifier: pulumi.Input<string>;
}
