import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for a Redshift-managed VPC endpoint.
 */
export declare class EndpointAccess extends pulumi.CustomResource {
    /**
     * Get an existing EndpointAccess resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EndpointAccess;
    /**
     * Returns true if the given object is an instance of EndpointAccess.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EndpointAccess;
    /**
     * The DNS address of the endpoint.
     */
    readonly address: pulumi.Output<string>;
    /**
     * A unique identifier for the cluster. You use this identifier to refer to the cluster for any subsequent cluster operations such as deleting or modifying. All alphabetical characters must be lower case, no hypens at the end, no two consecutive hyphens. Cluster name should be unique for all clusters within an AWS account
     */
    readonly clusterIdentifier: pulumi.Output<string>;
    /**
     * The time (UTC) that the endpoint was created.
     */
    readonly endpointCreateTime: pulumi.Output<string>;
    /**
     * The name of the endpoint.
     */
    readonly endpointName: pulumi.Output<string>;
    /**
     * The status of the endpoint.
     */
    readonly endpointStatus: pulumi.Output<string>;
    /**
     * The port number on which the cluster accepts incoming connections.
     */
    readonly port: pulumi.Output<number>;
    /**
     * The AWS account ID of the owner of the cluster.
     */
    readonly resourceOwner: pulumi.Output<string | undefined>;
    /**
     * The subnet group name where Amazon Redshift chooses to deploy the endpoint.
     */
    readonly subnetGroupName: pulumi.Output<string>;
    /**
     * The connection endpoint for connecting to an Amazon Redshift cluster through the proxy.
     */
    readonly vpcEndpoint: pulumi.Output<outputs.redshift.VpcEndpointProperties>;
    /**
     * A list of vpc security group ids to apply to the created endpoint access.
     */
    readonly vpcSecurityGroupIds: pulumi.Output<string[]>;
    /**
     * A list of Virtual Private Cloud (VPC) security groups to be associated with the endpoint.
     */
    readonly vpcSecurityGroups: pulumi.Output<outputs.redshift.EndpointAccessVpcSecurityGroup[]>;
    /**
     * Create a EndpointAccess resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EndpointAccessArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EndpointAccess resource.
 */
export interface EndpointAccessArgs {
    /**
     * A unique identifier for the cluster. You use this identifier to refer to the cluster for any subsequent cluster operations such as deleting or modifying. All alphabetical characters must be lower case, no hypens at the end, no two consecutive hyphens. Cluster name should be unique for all clusters within an AWS account
     */
    clusterIdentifier: pulumi.Input<string>;
    /**
     * The name of the endpoint.
     */
    endpointName: pulumi.Input<string>;
    /**
     * The AWS account ID of the owner of the cluster.
     */
    resourceOwner?: pulumi.Input<string>;
    /**
     * The subnet group name where Amazon Redshift chooses to deploy the endpoint.
     */
    subnetGroupName: pulumi.Input<string>;
    /**
     * A list of vpc security group ids to apply to the created endpoint access.
     */
    vpcSecurityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
}
