import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type Definition for Resiliency Policy.
 */
export declare class ResiliencyPolicy extends pulumi.CustomResource {
    /**
     * Get an existing ResiliencyPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResiliencyPolicy;
    /**
     * Returns true if the given object is an instance of ResiliencyPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResiliencyPolicy;
    /**
     * Data Location Constraint of the Policy.
     */
    readonly dataLocationConstraint: pulumi.Output<enums.resiliencehub.ResiliencyPolicyDataLocationConstraint | undefined>;
    /**
     * The resiliency policy.
     */
    readonly policy: pulumi.Output<outputs.resiliencehub.ResiliencyPolicyPolicyMap>;
    /**
     * Amazon Resource Name (ARN) of the Resiliency Policy.
     */
    readonly policyArn: pulumi.Output<string>;
    /**
     * Description of Resiliency Policy.
     */
    readonly policyDescription: pulumi.Output<string | undefined>;
    /**
     * Name of Resiliency Policy.
     */
    readonly policyName: pulumi.Output<string>;
    /**
     * Tags assigned to the resource. A tag is a label that you assign to an AWS resource. Each tag consists of a key/value pair.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Resiliency Policy Tier.
     */
    readonly tier: pulumi.Output<enums.resiliencehub.ResiliencyPolicyTier>;
    /**
     * Create a ResiliencyPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ResiliencyPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResiliencyPolicy resource.
 */
export interface ResiliencyPolicyArgs {
    /**
     * Data Location Constraint of the Policy.
     */
    dataLocationConstraint?: pulumi.Input<enums.resiliencehub.ResiliencyPolicyDataLocationConstraint>;
    /**
     * The resiliency policy.
     */
    policy: pulumi.Input<inputs.resiliencehub.ResiliencyPolicyPolicyMapArgs>;
    /**
     * Description of Resiliency Policy.
     */
    policyDescription?: pulumi.Input<string>;
    /**
     * Name of Resiliency Policy.
     */
    policyName?: pulumi.Input<string>;
    /**
     * Tags assigned to the resource. A tag is a label that you assign to an AWS resource. Each tag consists of a key/value pair.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Resiliency Policy Tier.
     */
    tier: pulumi.Input<enums.resiliencehub.ResiliencyPolicyTier>;
}
