import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::S3::AccessGrantsLocation resource is an Amazon S3 resource type hosted in an access grants instance which can be the target of S3 access grants.
 */
export declare class AccessGrantsLocation extends pulumi.CustomResource {
    /**
     * Get an existing AccessGrantsLocation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AccessGrantsLocation;
    /**
     * Returns true if the given object is an instance of AccessGrantsLocation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessGrantsLocation;
    /**
     * The Amazon Resource Name (ARN) of the specified Access Grants location.
     */
    readonly accessGrantsLocationArn: pulumi.Output<string>;
    /**
     * The unique identifier for the specified Access Grants location.
     */
    readonly accessGrantsLocationId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the access grant location's associated IAM role.
     */
    readonly iamRoleArn: pulumi.Output<string | undefined>;
    /**
     * Descriptor for where the location actually points
     */
    readonly locationScope: pulumi.Output<string | undefined>;
    /**
     * The AWS resource tags that you are adding to the S3 Access Grants location. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a AccessGrantsLocation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AccessGrantsLocationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AccessGrantsLocation resource.
 */
export interface AccessGrantsLocationArgs {
    /**
     * The Amazon Resource Name (ARN) of the access grant location's associated IAM role.
     */
    iamRoleArn?: pulumi.Input<string>;
    /**
     * Descriptor for where the location actually points
     */
    locationScope?: pulumi.Input<string>;
    /**
     * The AWS resource tags that you are adding to the S3 Access Grants location. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
