import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS::S3::MultiRegionAccessPoint is an Amazon S3 resource type that dynamically routes S3 requests to easily satisfy geographic compliance requirements based on customer-defined routing policies.
 */
export declare class MultiRegionAccessPoint extends pulumi.CustomResource {
    /**
     * Get an existing MultiRegionAccessPoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MultiRegionAccessPoint;
    /**
     * Returns true if the given object is an instance of MultiRegionAccessPoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MultiRegionAccessPoint;
    /**
     * The alias is a unique identifier to, and is part of the public DNS name for this Multi Region Access Point
     */
    readonly alias: pulumi.Output<string>;
    /**
     * The timestamp of the when the Multi Region Access Point is created
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The name you want to assign to this Multi Region Access Point.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The PublicAccessBlock configuration that you want to apply to this Multi Region Access Point. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html#access-control-block-public-access-policy-status 'The Meaning of Public' in the Amazon Simple Storage Service Developer Guide.
     */
    readonly publicAccessBlockConfiguration: pulumi.Output<outputs.s3.MultiRegionAccessPointPublicAccessBlockConfiguration | undefined>;
    /**
     * The list of buckets that you want to associate this Multi Region Access Point with.
     */
    readonly regions: pulumi.Output<outputs.s3.MultiRegionAccessPointRegion[]>;
    /**
     * Create a MultiRegionAccessPoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MultiRegionAccessPointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MultiRegionAccessPoint resource.
 */
export interface MultiRegionAccessPointArgs {
    /**
     * The name you want to assign to this Multi Region Access Point.
     */
    name?: pulumi.Input<string>;
    /**
     * The PublicAccessBlock configuration that you want to apply to this Multi Region Access Point. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html#access-control-block-public-access-policy-status 'The Meaning of Public' in the Amazon Simple Storage Service Developer Guide.
     */
    publicAccessBlockConfiguration?: pulumi.Input<inputs.s3.MultiRegionAccessPointPublicAccessBlockConfigurationArgs>;
    /**
     * The list of buckets that you want to associate this Multi Region Access Point with.
     */
    regions: pulumi.Input<pulumi.Input<inputs.s3.MultiRegionAccessPointRegionArgs>[]>;
}
