import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::SecurityHub::Insight resource represents the AWS Security Hub Insight in your account. An AWS Security Hub insight is a collection of related findings.
 */
export declare class Insight extends pulumi.CustomResource {
    /**
     * Get an existing Insight resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Insight;
    /**
     * Returns true if the given object is an instance of Insight.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Insight;
    /**
     * One or more attributes used to filter the findings included in the insight
     */
    readonly filters: pulumi.Output<outputs.securityhub.InsightAwsSecurityFindingFilters>;
    /**
     * The grouping attribute for the insight's findings
     */
    readonly groupByAttribute: pulumi.Output<string>;
    /**
     * The ARN of a Security Hub insight
     */
    readonly insightArn: pulumi.Output<string>;
    /**
     * The name of a Security Hub insight
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a Insight resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: InsightArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Insight resource.
 */
export interface InsightArgs {
    /**
     * One or more attributes used to filter the findings included in the insight
     */
    filters: pulumi.Input<inputs.securityhub.InsightAwsSecurityFindingFiltersArgs>;
    /**
     * The grouping attribute for the insight's findings
     */
    groupByAttribute: pulumi.Input<string>;
    /**
     * The name of a Security Hub insight
     */
    name?: pulumi.Input<string>;
}
