import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::SecurityHub::ProductSubscription resource represents a subscription to a service that is allowed to generate findings for your Security Hub account. One product subscription resource is created for each product enabled.
 */
export declare class ProductSubscription extends pulumi.CustomResource {
    /**
     * Get an existing ProductSubscription resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ProductSubscription;
    /**
     * Returns true if the given object is an instance of ProductSubscription.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProductSubscription;
    /**
     * The generic ARN of the product being subscribed to
     */
    readonly productArn: pulumi.Output<string>;
    /**
     * The ARN of the product subscription for the account
     */
    readonly productSubscriptionArn: pulumi.Output<string>;
    /**
     * Create a ProductSubscription resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProductSubscriptionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ProductSubscription resource.
 */
export interface ProductSubscriptionArgs {
    /**
     * The generic ARN of the product being subscribed to
     */
    productArn: pulumi.Input<string>;
}
