import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SecurityLake::DataLake
 */
export declare class DataLake extends pulumi.CustomResource {
    /**
     * Get an existing DataLake resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DataLake;
    /**
     * Returns true if the given object is an instance of DataLake.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DataLake;
    /**
     * The Amazon Resource Name (ARN) created by you to provide to the subscriber.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Provides encryption details of the Amazon Security Lake object.
     */
    readonly encryptionConfiguration: pulumi.Output<outputs.securitylake.DataLakeEncryptionConfiguration | undefined>;
    /**
     * You can customize Security Lake to store data in your preferred AWS Regions for your preferred amount of time. Lifecycle management can help you comply with different compliance requirements. For more details, see [Lifecycle management](https://docs.aws.amazon.com//security-lake/latest/userguide/lifecycle-management.html) in the Amazon Security Lake User Guide.
     */
    readonly lifecycleConfiguration: pulumi.Output<outputs.securitylake.DataLakeLifecycleConfiguration | undefined>;
    /**
     * The Amazon Resource Name (ARN) used to index AWS Glue table partitions that are generated by the ingestion and normalization of AWS log sources and custom sources.
     */
    readonly metaStoreManagerRoleArn: pulumi.Output<string | undefined>;
    /**
     * Provides replication details of Amazon Security Lake object.
     */
    readonly replicationConfiguration: pulumi.Output<outputs.securitylake.DataLakeReplicationConfiguration | undefined>;
    /**
     * The ARN for the Amazon Security Lake Amazon S3 bucket.
     */
    readonly s3BucketArn: pulumi.Output<string>;
    /**
     * An array of objects, one for each tag to associate with the data lake configuration. For each tag, you must specify both a tag key and a tag value. A tag value cannot be null, but it can be an empty string.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DataLake resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DataLakeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DataLake resource.
 */
export interface DataLakeArgs {
    /**
     * Provides encryption details of the Amazon Security Lake object.
     */
    encryptionConfiguration?: pulumi.Input<inputs.securitylake.DataLakeEncryptionConfigurationArgs>;
    /**
     * You can customize Security Lake to store data in your preferred AWS Regions for your preferred amount of time. Lifecycle management can help you comply with different compliance requirements. For more details, see [Lifecycle management](https://docs.aws.amazon.com//security-lake/latest/userguide/lifecycle-management.html) in the Amazon Security Lake User Guide.
     */
    lifecycleConfiguration?: pulumi.Input<inputs.securitylake.DataLakeLifecycleConfigurationArgs>;
    /**
     * The Amazon Resource Name (ARN) used to index AWS Glue table partitions that are generated by the ingestion and normalization of AWS log sources and custom sources.
     */
    metaStoreManagerRoleArn?: pulumi.Input<string>;
    /**
     * Provides replication details of Amazon Security Lake object.
     */
    replicationConfiguration?: pulumi.Input<inputs.securitylake.DataLakeReplicationConfigurationArgs>;
    /**
     * An array of objects, one for each tag to associate with the data lake configuration. For each tag, you must specify both a tag key and a tag value. A tag value cannot be null, but it can be an empty string.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
