import * as pulumi from "@pulumi/pulumi";
/**
 * Schema for SQS QueueInlinePolicy
 */
export declare class QueueInlinePolicy extends pulumi.CustomResource {
    /**
     * Get an existing QueueInlinePolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): QueueInlinePolicy;
    /**
     * Returns true if the given object is an instance of QueueInlinePolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is QueueInlinePolicy;
    /**
     * A policy document that contains permissions to add to the specified SQS queue
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SQS::QueueInlinePolicy` for more information about the expected schema for this property.
     */
    readonly policyDocument: pulumi.Output<any>;
    /**
     * The URL of the SQS queue.
     */
    readonly queue: pulumi.Output<string>;
    /**
     * Create a QueueInlinePolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: QueueInlinePolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a QueueInlinePolicy resource.
 */
export interface QueueInlinePolicyArgs {
    /**
     * A policy document that contains permissions to add to the specified SQS queue
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SQS::QueueInlinePolicy` for more information about the expected schema for this property.
     */
    policyDocument: any;
    /**
     * The URL of the SQS queue.
     */
    queue: pulumi.Input<string>;
}
