import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Transfer::Connector
 */
export declare function getConnector(args: GetConnectorArgs, opts?: pulumi.InvokeOptions): Promise<GetConnectorResult>;
export interface GetConnectorArgs {
    /**
     * A unique identifier for the connector.
     */
    connectorId: string;
}
export interface GetConnectorResult {
    /**
     * Specifies the access role for the connector.
     */
    readonly accessRole?: string;
    /**
     * Specifies the unique Amazon Resource Name (ARN) for the connector.
     */
    readonly arn?: string;
    /**
     * Configuration for an AS2 connector.
     */
    readonly as2Config?: outputs.transfer.As2ConfigProperties;
    /**
     * A unique identifier for the connector.
     */
    readonly connectorId?: string;
    /**
     * Specifies the logging role for the connector.
     */
    readonly loggingRole?: string;
    /**
     * Security policy for SFTP Connector
     */
    readonly securityPolicyName?: string;
    /**
     * The list of egress IP addresses of this connector. These IP addresses are assigned automatically when you create the connector.
     */
    readonly serviceManagedEgressIpAddresses?: string[];
    /**
     * Configuration for an SFTP connector.
     */
    readonly sftpConfig?: outputs.transfer.SftpConfigProperties;
    /**
     * Key-value pairs that can be used to group and search for connectors. Tags are metadata attached to connectors for any purpose.
     */
    readonly tags?: outputs.Tag[];
    /**
     * URL for Connector
     */
    readonly url?: string;
}
/**
 * Resource Type definition for AWS::Transfer::Connector
 */
export declare function getConnectorOutput(args: GetConnectorOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConnectorResult>;
export interface GetConnectorOutputArgs {
    /**
     * A unique identifier for the connector.
     */
    connectorId: pulumi.Input<string>;
}
