import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Transfer::WebApp
 */
export declare function getWebApp(args: GetWebAppArgs, opts?: pulumi.InvokeOptions): Promise<GetWebAppResult>;
export interface GetWebAppArgs {
    /**
     * Specifies the unique Amazon Resource Name (ARN) for the web app.
     */
    arn: string;
}
export interface GetWebAppResult {
    /**
     * The AccessEndpoint is the URL that you provide to your users for them to interact with the Transfer Family web app. You can specify a custom URL or use the default value.
     */
    readonly accessEndpoint?: string;
    /**
     * Specifies the unique Amazon Resource Name (ARN) for the web app.
     */
    readonly arn?: string;
    /**
     * You can provide a structure that contains the details for the identity provider to use with your web app.
     *
     * For more details about this parameter, see [Configure your identity provider for Transfer Family web apps](https://docs.aws.amazon.com//transfer/latest/userguide/webapp-identity-center.html) .
     */
    readonly identityProviderDetails?: outputs.transfer.WebAppIdentityProviderDetails;
    /**
     * Key-value pairs that can be used to group and search for web apps.
     */
    readonly tags?: outputs.Tag[];
    /**
     * A structure that contains the customization fields for the web app. You can provide a title, logo, and icon to customize the appearance of your web app.
     */
    readonly webAppCustomization?: outputs.transfer.WebAppCustomization;
    /**
     * A unique identifier for the web app.
     */
    readonly webAppId?: string;
    /**
     * A union that contains the value for number of concurrent connections or the user sessions on your web app.
     */
    readonly webAppUnits?: outputs.transfer.WebAppUnitsProperties;
}
/**
 * Resource Type definition for AWS::Transfer::WebApp
 */
export declare function getWebAppOutput(args: GetWebAppOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWebAppResult>;
export interface GetWebAppOutputArgs {
    /**
     * Specifies the unique Amazon Resource Name (ARN) for the web app.
     */
    arn: pulumi.Input<string>;
}
