import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Creates a listener for a service. Before you start using your Amazon VPC Lattice service, you must add one or more listeners. A listener is a process that checks for connection requests to your services.
 */
export declare function getListener(args: GetListenerArgs, opts?: pulumi.InvokeOptions): Promise<GetListenerResult>;
export interface GetListenerArgs {
    /**
     * The Amazon Resource Name (ARN) of the listener.
     */
    arn: string;
}
export interface GetListenerResult {
    /**
     * The Amazon Resource Name (ARN) of the listener.
     */
    readonly arn?: string;
    /**
     * The action for the default rule. Each listener has a default rule. The default rule is used if no other rules match.
     */
    readonly defaultAction?: outputs.vpclattice.ListenerDefaultAction;
    /**
     * The ID of the listener.
     */
    readonly id?: string;
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    readonly serviceArn?: string;
    /**
     * The ID of the service.
     */
    readonly serviceId?: string;
    /**
     * The tags for the listener.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Creates a listener for a service. Before you start using your Amazon VPC Lattice service, you must add one or more listeners. A listener is a process that checks for connection requests to your services.
 */
export declare function getListenerOutput(args: GetListenerOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetListenerResult>;
export interface GetListenerOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the listener.
     */
    arn: pulumi.Input<string>;
}
