import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * VpcLattice ResourceConfiguration CFN resource
 */
export declare class ResourceConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing ResourceConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResourceConfiguration;
    /**
     * Returns true if the given object is an instance of ResourceConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResourceConfiguration;
    /**
     * Specifies whether the resource configuration can be associated with a sharable service network.
     */
    readonly allowAssociationToSharableServiceNetwork: pulumi.Output<boolean | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the resource configuration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the resource configuration.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The name of the resource configuration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * (SINGLE, GROUP, CHILD) The TCP port ranges that a consumer can use to access a resource configuration (for example: 1-65535). You can separate port ranges using commas (for example: 1,2,22-30).
     */
    readonly portRanges: pulumi.Output<string[] | undefined>;
    /**
     * (SINGLE, GROUP) The protocol accepted by the resource configuration.
     */
    readonly protocolType: pulumi.Output<enums.vpclattice.ResourceConfigurationProtocolType | undefined>;
    /**
     * The auth type for the resource configuration.
     */
    readonly resourceConfigurationAuthType: pulumi.Output<enums.vpclattice.ResourceConfigurationAuthType | undefined>;
    /**
     * Identifies the resource configuration in one of the following ways:
     *
     * - *Amazon Resource Name (ARN)* - Supported resource-types that are provisioned by AWS services, such as RDS databases, can be identified by their ARN.
     * - *Domain name* - Any domain name that is publicly resolvable.
     * - *IP address* - For IPv4 and IPv6, only IP addresses in the VPC are supported.
     */
    readonly resourceConfigurationDefinition: pulumi.Output<outputs.vpclattice.ResourceConfigurationDefinition0Properties | outputs.vpclattice.ResourceConfigurationDefinition1Properties | outputs.vpclattice.ResourceConfigurationDefinition2Properties | undefined>;
    /**
     * The ID of the group resource configuration.
     */
    readonly resourceConfigurationGroupId: pulumi.Output<string | undefined>;
    /**
     * The type of resource configuration. A resource configuration can be one of the following types:
     *
     * - *SINGLE* - A single resource.
     * - *GROUP* - A group of resources. You must create a group resource configuration before you create a child resource configuration.
     * - *CHILD* - A single resource that is part of a group resource configuration.
     * - *ARN* - An AWS resource.
     */
    readonly resourceConfigurationType: pulumi.Output<enums.vpclattice.ResourceConfigurationType>;
    /**
     * The ID of the resource gateway.
     */
    readonly resourceGatewayId: pulumi.Output<string | undefined>;
    /**
     * The tags for the resource configuration.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ResourceConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ResourceConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResourceConfiguration resource.
 */
export interface ResourceConfigurationArgs {
    /**
     * Specifies whether the resource configuration can be associated with a sharable service network.
     */
    allowAssociationToSharableServiceNetwork?: pulumi.Input<boolean>;
    /**
     * The name of the resource configuration.
     */
    name?: pulumi.Input<string>;
    /**
     * (SINGLE, GROUP, CHILD) The TCP port ranges that a consumer can use to access a resource configuration (for example: 1-65535). You can separate port ranges using commas (for example: 1,2,22-30).
     */
    portRanges?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * (SINGLE, GROUP) The protocol accepted by the resource configuration.
     */
    protocolType?: pulumi.Input<enums.vpclattice.ResourceConfigurationProtocolType>;
    /**
     * The auth type for the resource configuration.
     */
    resourceConfigurationAuthType?: pulumi.Input<enums.vpclattice.ResourceConfigurationAuthType>;
    /**
     * Identifies the resource configuration in one of the following ways:
     *
     * - *Amazon Resource Name (ARN)* - Supported resource-types that are provisioned by AWS services, such as RDS databases, can be identified by their ARN.
     * - *Domain name* - Any domain name that is publicly resolvable.
     * - *IP address* - For IPv4 and IPv6, only IP addresses in the VPC are supported.
     */
    resourceConfigurationDefinition?: pulumi.Input<inputs.vpclattice.ResourceConfigurationDefinition0PropertiesArgs | inputs.vpclattice.ResourceConfigurationDefinition1PropertiesArgs | inputs.vpclattice.ResourceConfigurationDefinition2PropertiesArgs>;
    /**
     * The ID of the group resource configuration.
     */
    resourceConfigurationGroupId?: pulumi.Input<string>;
    /**
     * The type of resource configuration. A resource configuration can be one of the following types:
     *
     * - *SINGLE* - A single resource.
     * - *GROUP* - A group of resources. You must create a group resource configuration before you create a child resource configuration.
     * - *CHILD* - A single resource that is part of a group resource configuration.
     * - *ARN* - An AWS resource.
     */
    resourceConfigurationType: pulumi.Input<enums.vpclattice.ResourceConfigurationType>;
    /**
     * The ID of the resource gateway.
     */
    resourceGatewayId?: pulumi.Input<string>;
    /**
     * The tags for the resource configuration.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
