import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::Wisdom::AIGuardrailVersion Resource Type
 */
export declare class AiGuardrailVersion extends pulumi.CustomResource {
    /**
     * Get an existing AiGuardrailVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AiGuardrailVersion;
    /**
     * Returns true if the given object is an instance of AiGuardrailVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AiGuardrailVersion;
    /**
     * The ARN of the AI guardrail version.
     */
    readonly aiGuardrailArn: pulumi.Output<string>;
    /**
     * The ID of the AI guardrail version.
     */
    readonly aiGuardrailId: pulumi.Output<string>;
    /**
     * The ID of the AI guardrail version.
     */
    readonly aiGuardrailVersionId: pulumi.Output<string>;
    /**
     * The ARN of the AI guardrail version assistant.
     */
    readonly assistantArn: pulumi.Output<string>;
    /**
     * The ID of the AI guardrail version assistant.
     */
    readonly assistantId: pulumi.Output<string>;
    /**
     * The modified time of the AI guardrail version in seconds.
     */
    readonly modifiedTimeSeconds: pulumi.Output<number | undefined>;
    /**
     * The version number for this AI Guardrail version.
     */
    readonly versionNumber: pulumi.Output<number>;
    /**
     * Create a AiGuardrailVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AiGuardrailVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AiGuardrailVersion resource.
 */
export interface AiGuardrailVersionArgs {
    /**
     * The ID of the AI guardrail version.
     */
    aiGuardrailId: pulumi.Input<string>;
    /**
     * The ID of the AI guardrail version assistant.
     */
    assistantId: pulumi.Input<string>;
    /**
     * The modified time of the AI guardrail version in seconds.
     */
    modifiedTimeSeconds?: pulumi.Input<number>;
}
