import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Wisdom::AIPrompt Resource Type
 */
export declare function getAiPrompt(args: GetAiPromptArgs, opts?: pulumi.InvokeOptions): Promise<GetAiPromptResult>;
export interface GetAiPromptArgs {
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    aiPromptId: string;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: string;
}
export interface GetAiPromptResult {
    /**
     * The Amazon Resource Name (ARN) of the AI Prompt.
     */
    readonly aiPromptArn?: string;
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    readonly aiPromptId?: string;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Q in Connect assistant.
     */
    readonly assistantArn?: string;
    /**
     * The description of the AI Prompt.
     */
    readonly description?: string;
    readonly modifiedTimeSeconds?: number;
    /**
     * The configuration of the prompt template for this AI Prompt.
     */
    readonly templateConfiguration?: outputs.wisdom.AiPromptAiPromptTemplateConfiguration;
}
/**
 * Definition of AWS::Wisdom::AIPrompt Resource Type
 */
export declare function getAiPromptOutput(args: GetAiPromptOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAiPromptResult>;
export interface GetAiPromptOutputArgs {
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    aiPromptId: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: pulumi.Input<string>;
}
